g2gtools package
================

Submodules
----------

.. toctree::

   g2gtools.bamsam
   g2gtools.bed
   g2gtools.bins
   g2gtools.chain
   g2gtools.exceptions
   g2gtools.fasta
   g2gtools.g2g
   g2gtools.g2g_commands
   g2gtools.g2g_utils
   g2gtools.gtf
   g2gtools.kmer
   g2gtools.seq_offsets
   g2gtools.sequence
   g2gtools.vcf

Module contents
---------------

.. automodule:: g2gtools
    :members:
    :undoc-members:
    :show-inheritance:
